@@ -475,9 +475,8 @@ RS_GGOBI(setCaseGlyphs)(USER_OBJECT_ vals, USER_OBJECT_ sizes, USER_OBJECT_ whic
       GGOBI(setCaseGlyph)(id, INTEGER_DATA(vals)[i], INTEGER_DATA(sizes)[i], d, gg);
     } 
 
-#if 0
     clusters_set (d, gg);
-#endif
+    cluster_table_update (d, gg);  /* dfs, May 20 2005 */
     displays_plot(NULL, FULL, gg);
     gdk_flush();
   }
@@ -580,7 +579,8 @@ RS_GGOBI(setCaseColors)(USER_OBJECT_ vals, USER_OBJECT_ which, USER_OBJECT_ data
       	 GGOBI(setCaseColor)(id, INTEGER_DATA(vals)[i] - 1, d, gg);
        }
       
-       clusters_set (d, gg);
+       clusters_set (d, gg);          /* reactivated, May 20 2005 */
+       cluster_table_update (d, gg);  /* added, May 20 2005 -- dfs */
        displays_plot(NULL, FULL, gg);
        gdk_flush();
   }
